import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This demo displays a chart with two area series.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame implements ItemListener,AdjustmentListener {
    Graph graph;
    AreaSerie as1,as2;

    JCheckBox is3D,isHorizontal;

    JScrollBar depth;

    public Main() {
	
	// A title for the frame
	setTitle("The JetChart Library - Area Chart Demo");
	
	// Values for the series
	double[] values1={250,200,250,280,300,240,230,160,180,210};
	double[] values2={220,-150,60,100,130,160,140,110,100,80};
	
	// Creates two line series
        as1=new AreaSerie(values1,"Area Series 1");
        as2=new AreaSerie(values2,"Area Series 2");
		
	// Sets area series properties
	setAreaSeriesProperties();

	// Labels for chart
	String[] labels={"label1","label2","label3","label4","label5",
			 "label6","label7","label8","label9","label10"};
	
	// Creates graphic context, passing labels
	graph=new Graph(labels);
	
	// Sets chart optional properties
	setChartProperties();
	
	// Adds the two area series to the graphic context
	graph.addSerie(as1);
	graph.addSerie(as2);
	
        Container ct=getContentPane();
	ct.add("Center",graph);
	
	// Creates a top panel to layout components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(400,360);

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for 3D state and chart orientation
    public void itemStateChanged(ItemEvent evt) {
	if (evt.getSource()==is3D) {
	    graph.set3DEnabled(is3D.isSelected());
	    depth.setEnabled(is3D.isSelected());
	}
	else if (evt.getSource()==isHorizontal) {
	    boolean hor=isHorizontal.isSelected();
	    graph.setHorizontalGraphEnabled(hor);
	    if (!hor) {
		graph.getLeftTitle().setText("Values Title");
		graph.getBottomTitle().setText("Labels Title");
	    }
	    else {
		graph.getLeftTitle().setText("Labels Title");
		graph.getBottomTitle().setText("Values Title");
	    }
	}
	graph.repaint();
    }

    // Event handler for chart depth adjustment
    public void adjustmentValueChanged(AdjustmentEvent evt) {
	if (evt.getSource()==depth) {
	    graph.setVDepth(depth.getValue());
	    graph.setHDepth(depth.getValue());
	    graph.repaint();
	}
    }
	    
	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
	//  Checkbox for 3D property.
	is3D=new JCheckBox("3D");
	is3D.setFont(new Font("Arial",Font.PLAIN,10));
	is3D.addItemListener(this);
	
	// Checkbox for chart orientation property
	isHorizontal=new JCheckBox("Horizontal");
	isHorizontal.setFont(new Font("Arial",Font.PLAIN,10));
	isHorizontal.addItemListener(this);

	// Scrollbar for chart depth adjustment
	depth=new JScrollBar(Scrollbar.HORIZONTAL,5,1,0,30);
        depth.setPreferredSize(new Dimension(150,depth.getPreferredSize().height));
	
	depth.setEnabled(false);
	depth.addAdjustmentListener(this);
	
	topPanel.add(is3D);
	topPanel.add(isHorizontal);
	topPanel.add(new Label("3D depth:"));
	topPanel.add(depth);
    
        Container ct=getContentPane();
	ct.add("North",topPanel);

    }

    private void setAreaSeriesProperties() {
	// Sets color
	as1.setColor(Color.red);
	as2.setColor(Color.green);
	as1.setAreaLinesEnabled(true);
	    
    }

    private void setChartProperties() {
	
	// Sets chart title
	String[] title={"The JetChart Library","Demo with two area series"};
	graph.setTitle(title);
	
	// Sets labels title
	graph.getBottomTitle().setText("Labels Title");

	// Sets values title
	graph.getLeftTitle().setText("Values Title");

	// Applies gradient colors to graphic context
	graph.setGradientColors(Color.yellow,new Color(51,102,255));
	//graph.setGradientOrientation(graph.LEFT_TO_RIGHT);

	// Enables chart and legend dragging. A double-click over chart alternates
	// between moving chart and scale adjustment.
	graph.setDraggingEnabled(true);

	// Enables grid and sets grid color
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(Color.magenta);

	// Sets legend orientation and position. Legend can be dinamically
	// dragged, if the Graph draggable property is set to true.
	graph.getLegend().setOrientation(Legend.HORIZONTAL);
	//graph.getLegend().setPosition(Legend.RIGHT);
	//graph.getLegend().setPosition(Legend.LEFT);

	// Sets format for values.
	graph.setValueFormat("###,###0.00");
    
	// Sets depth for vertical graph.
	graph.setVDepth(5);

	// Sets depth for horizontal graph.
	graph.setHDepth(5);

	// Enables tooltip
	graph.getToolTip().setEnabled(true);
    }

    public static void main(String[] args) {
	new Main();
    }
}
