import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 * This application demonstrates how to configure and display series tooltips simultaneously.
 * Tooltips  are  simultaneously  displayed in  2D charts only. If multiple tooltips display
 * is enabled, only one coordinate is checked to verify if mouse cursor is located within a
 * series data point area. Thus, if more than one series are simultaneously displayed and 
 * mouse cursor is moved on a coordinate shared by data points of distinct series, these 
 * data points tooltips are simultaneously displayed.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame {

    public Main() {

        setTitle("The JetChart Library - Multiple Tooltips Demo");

        addWindowListener(new WindowAdapter() {
           public void windowClosing(WindowEvent evt) {
              System.exit(0);
           }
        });

	Graph graph=new Graph();
	graph.setTitle(new String[]{"The JetChart Library","Multiple Tooltips Demo"});

	// Sets the labels color and the scale color to red. See JetChart documentation 
	// about the GraphSet class for further details.
	graph.getGraphSet(0).setLabelsColor(Color.red);
	graph.getGraphSet(0).getScale().setColor(Color.red);

	// Enables grid and sets its color.
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(new Color(128,128,128));
	
	graph.setDraggingEnabled(true);

	graph.setStartDate("11092000");

	// Enables tooltip display. 
	graph.getToolTip().setEnabled(true);

	// Try enabling the following lines to activate tooltip timer with a delay of 
	// 300 ms. Default delay is 500 ms.
	//graph.getToolTip().setTimerEnabled(true);
	//graph.getToolTip().setDelay(300); //milisseconds
	
	// Enables multiple tooltips display. Multiple tooltips display has no effect with 3D charts.
	graph.getToolTip().setMultipleEnabled(true);

	// Sets the distance between tooltips to 20 pixels. Default value is 4.
	graph.getToolTip().setGap(20);

	// Sets the tooltip pointer type to a line. Uncomment this line to see effect.
	//graph.getToolTip().setPointerType(ToolTip.LINE);

	// Sets tooltip border color to match respective series color. Uncomment the following lines
	// to see effect. The tooltip pointer type must be set to NONE.
	//graph.getToolTip().setPointerType(ToolTip.NONE);
	//graph.getToolTip().setMatchingBorderEnabled(true);

	// Disables border around tooltip. Uncomment this line to see effect.
	//graph.getToolTip().setBorderEnabled(false);
	graph.getToolTip().setBackground(new Color(255,255,204));

	// Enables simultaneous highlight of data points, synchronized with multiple tooltips display.
	graph.setMultipleHighlightEnabled(true);

	// Creates a bar series and enables highlight.
        BarSerie bs=new BarSerie(new double[]{200,300,400,500,600,600,500,400,300,200},"Bar Series");
	bs.setColor(Color.blue);
	bs.setHighlightEnabled(true);

	// Creates a line series, enables highlight, disables marks  and set its thickness to 3 pixels.
        LineSerie ls=new LineSerie(new double[]{50,100,320,400,120,54,345,234,111,434},"Line Series");
	ls.setColor(Color.green.darker());
	ls.setHighlightEnabled(true);
	ls.setHighlightColor(Color.magenta);
	ls.setThickness(3);
	ls.setMarksEnabled(false);

	graph.addSerie(bs);
	graph.addSerie(ls);

        Container ct=getContentPane();

	ct.add("Center",graph);

        setSize(400,250);
        setVisible(true);

    }

    public static void main(String[] args) {
	Main m=new Main();
    }
}
