import com.jinsight.jetchart.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;


/**
 * A regression line  is a statistical tool used  to  predict future values
 * from  past values. This demo paints a linear regression line  based   on 
 * real data  representing world grain production evolution across a period
 * that spans  from 1950 to 1995. Chart labels  and  series values are read
 * from an XML file, using JetChart built-in XML parsing capabilities.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */
public class Main extends JFrame {

    LineSerie ls;
    Graph graph;

    public Main() {

	setTitle("The JetChart Library - Regression Line demo");

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	// Creates chart context.
	createGraph();

	// Enables left title.
	enableLeftTitle();

	// Enables bottom title.
	enableBottomTitle();
	
	// Enables grid.
	enableGrid();

	// Creates line series and enables regression line.
	createLineSeries();

	// Reads data.
	readXMLData();

	// Configurates scale.
	configScale();

        Container ct=getContentPane();

	ct.add("Center",graph);

	setSize(500,400);

	setVisible(true);

    }

    private void createGraph() {

	graph=new Graph();
	
	graph.setTitle(new String[]{"World Grain Production","1950-1995"});
	graph.setTitleFont(new Font("SansSerif",Font.PLAIN,14));
        graph.setBackground(new Color(255,255,208));

    }
    
    private void enableLeftTitle() {
	LeftTitle lt=graph.getLeftTitle();
	lt.setFont(new Font("SansSerif",Font.PLAIN,12));
	lt.setText("Total - Million tons");
    }

    private void enableBottomTitle() {
	BottomTitle bt=graph.getBottomTitle();
	bt.setFont(new Font("SansSerif",Font.PLAIN,12));
	bt.setText("Year");
    }

    private void enableGrid() {
	GraphSet graphSet=graph.getGraphSet(0);
	Grid grid=graphSet.getGrid();
	grid.setEnabled(true);
    }

    private void createLineSeries() {

	ls=new LineSerie();
	ls.setColor(Color.blue);
	ls.setMarksEnabled(false);
	ls.setThickness(2);
	
	// Enables the regression line.
	RegressionLine rl=ls.getRegressionLine();
	rl.setEnabled(true);
	rl.setColor(Color.red);

	// Adds series to the chart context.
	graph.addSerie(ls);
	graph.setZoomEnabled(true);

    }

    private void readXMLData() {
	
	try {
	    // Data is read from the chart.xml file.
	    FileReader fr=new FileReader("chart.xml");
	    graph.readXMLData(fr);
	}
	catch (IOException e) {
	    e.printStackTrace();
	}

    }

    private void configScale() {

	GraphSet graphSet=graph.getGraphSet(0);

	Scale scale=graphSet.getScale();

	scale.setAutoScaleEnabled(false);

	scale.setMaxValue(2000);
	scale.setIncrement(400);

	scale.setValueFormat("#,###");
    }

	
    public static void main(String[] args) {
	new Main();
    }

}
