import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import com.jinsight.jetchart.*;
import com.jinsight.svg.*;
import java.io.*;

public class SVG_Swing_Example extends JFrame implements ActionListener {

    CustomGraph graph;

    // This flag is checked by CustomGraph, a subclass of Graph, 
    // to verify if an SVG encoding process has been started.
    boolean isGeneratingSVG;

    public SVG_Swing_Example() {

	addWindowListener(new WindowAdapter() {
		public void windowClosing(WindowEvent evt) {
		    System.exit(0);
		}
	    });

	JPanel topPanel=new JPanel();
	JButton b=new JButton("Generate SVG");
	b.addActionListener(this);

	topPanel.add(b);

	getContentPane().add("North",topPanel);

	graph=new CustomGraph(new String[]{"l1","l2","l3","l4","l5","l6","l7"});

	graph.setTitle(new String[]{"The JetChart Library","SVG Encoding Demo"});

	graph.set3DEnabled(true);
	
	graph.getGraphSet(0).getGrid().setEnabled(true);

	graph.setGradientColors(Color.blue,Color.yellow);

	BarSerie bs=new BarSerie();
	bs.setValues(new double[]{100,80,60,40,90,40,140});
	bs.setColor(Color.cyan);
	bs.setTitle("Bar series");

	graph.addSerie(bs);

	getContentPane().add("Center",graph);

	setSize(500,400);

	setVisible(true);

    }
    
    public void actionPerformed(ActionEvent evt) {

	isGeneratingSVG=true;

	ChartEncoder ce=new ChartEncoder(graph);

	OutputStream out=null;

	try {

	    File f=new File("chart.svg");
	    out=new FileOutputStream(f);

	    // Encodes chart and outputs SVG code to the chart.svg file.
	    ce.svgEncode(out,false,SVGEncoder.HIGH_QUALITY);

	}
	catch (IOException e) {
	    e.printStackTrace();
	}
	finally {

	    isGeneratingSVG=false;

	    try {
		if (out!=null)
		    out.close();
	    }
	    catch (IOException e) {
		e.printStackTrace();
	    }
	}

    }

    private class CustomGraph extends Graph {

	public void paint(Graphics g) {

	    if (isGeneratingSVG) 
		paintComponent(g);
	    else
		super.paint(g);

	}

    }
    
    public static void main(String[] args) {
	new SVG_Swing_Example();
    }
}

	

	
